#! /bin/bash

#
# call Drush c2pa_kms_sign command and pass all command line arguments to it, including stdin
#
LOGFILE="/var/www/html/c2pa/c2pa_sign_aws_kms.log"
DEBUGGING=''
function debug () {
  DEBUGGING="${DEBUGGING}\n${1}"
  echo "${1}" >> ${LOGFILE}
}
PWD=`pwd`
debug "PWD: ${PWD}"
debug "-----------env"
#echo "-----------env" >> ${LOGFILE}
#debug `env`
env  >> ${LOGFILE}
#echo "-----------end env"  >> ${LOGFILE}
debug "-----------end env"

SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )

# find drush executable in the path

# find the docroot by recursively traversing up the tree until the index.php file is found
function find_docroot () {
    debug "CURRENT_DIR ${CURRENT_DIR}"
    FILE_TO_CHECK="${CURRENT_DIR}/index.php"
    if [ -f ${FILE_TO_CHECK} ]; then
        # found docroot, set the variable
        DOCROOT=${CURRENT_DIR}
    else
        # did not find DOCROOT, go up one level
        CURRENT_DIR=`dirname "${CURRENT_DIR}"`
        find_docroot
    fi
}


# find Drush in the vendor directory by recursively traversing up the directory tree until it is found in the vendor directory
function find_drush () {
    FILE_TO_CHECK="${CURRENT_DIR}/vendor/bin/drush"
    if [ -f ${FILE_TO_CHECK} ]; then
        # found it, set the variable
        DRUSH="${FILE_TO_CHECK}"
    else
        # try parent directory
        CURRENT_DIR=`dirname "${CURRENT_DIR}"`
        find_drush
    fi
}


CURRENT_DIR=${SCRIPT_DIR}
find_docroot
CURRENT_DIR=${SCRIPT_DIR}
find_drush


if [[ ! -f ${DRUSH} ]]; then
    # send the message to stderr
    >&2 echo "debugging information"
    >&2 echo ${DEBUGGING}
    >&2 echo "Drush not found: ${DRUSH}";
    exit 1;
fi
debug "DOCROOT: ${DOCROOT}"
if [[ ! -d ${DOCROOT} ]]; then
    # send the message to stderr
    >&2 echo "DOCROOT not found";
    exit 1;
fi

# execute drush command
COMMAND="$DRUSH --root=${DOCROOT} c2pa_kms_sign $@"
# output the command to stderr
debug "drush command being run: ${COMMAND}"

# redirect stderr for the command to the ERRORS variable while keeping the stdout going to stdout
# in theory this is the way it should work
# 2>&1 - redirect stderr (2) to stdin (1) to be save in ERRORS
# >&3 - redirect stdout to pipe 3 (newly declared)
# 3>&- - redirect pipe 3 (was stdout) to stdout (-)
# 3>&1 - redirect pipe 3 to stdout (1)
{ ERRORS=$(eval ${COMMAND} 2>&1 >&3 3>&-); } 3>&1

#eval $COMMAND

status=$?
if [ $status -ne 0 ]; then
  >&2 echo "debugging information"
  >&2 echo ${DEBUGGING}
  >&2 echo "errors:"
  >&2 echo ${ERRORS}
fi
